QoS framework for Python and Linux
==================================

When setting a QoS with TC with a shell script, the syntax is not easy to read.
This framework helps you to set all your rules easily, in a hierarchical way.

Documentation: https://pyqos.readthedocs.org/en/dev/

Dependencies
------------
  * python 3.4 (it certainly works with prior versions, just not tested)


Example
-------

There is an example about how using the framework in the `example` folder.


Contributors
------------

 * [Anthony Ruhier](https://github.com/Anthony25)
 * [Thomas Gagneret](https://github.com/tgagneret)


Special thanks
--------------
 * [Flask Project:](https://github.com/mitsuhiko/flask) Some parts about the
    application and configuration were inspired a lot from it.


Readings about tc
-----------------

 * http://wiki.linuxwall.info/doku.php/en:ressources:dossiers:networking:traffic_control
   : General explanations about QoS and tc
 * http://luxik.cdi.cz/~devik/qos/htb/manual/userg.htm : Details about htb
 * http://joekane.eu/cisco-rate-limit-burst-explained/ : Details about burst
   and cburst and how to define it.


License
-------

Tool under the BSD license. Do not hesitate to report bugs, ask me some
questions or do some pull request if you want to !
